@@ -20,7 +20,7 @@
 ##' @param copula is a copula of the desired family
 ##' @param x the data
 ##' @param N the number of bootstrap or multiplier replications
-##' @param method estimation method for the unknown parameter
+##' @param estim.method estimation method for the unknown parameter
 ##' @param simulation parametric bootstrap or multiplier
 ##' @param verbose display progress bar if TRUE
 ##' @param print.every is deprecated
@@ -28,12 +28,17 @@
 ##' @param optim.control for fitting
 ##' @return an object of class 'htest'
 ##' @author Ivan Kojadinovic
-gofCopula <- function(copula, x, N = 1000, method = "mpl",
+gofCopula <- function(copula, x, N = 1000,
+                      method = c("Sn", "AnChisq", "AnGamma", "SnB", "SnC"),
+                      estim.method = c("mpl", "ml", "irho", "itau"),
                       simulation = c("pb", "mult"),
 		      verbose = TRUE, print.every = NULL,
                       optim.method = "BFGS", optim.control = list(maxit=20))
 {
-    x <- as.matrix(x)
+    if(!is.matrix(x)) {
+        warning("coercing 'x' to a matrix")
+        x <- as.matrix(x); stopifnot(is.matrix(x))
+    }
     n <- nrow(x)
     p <- ncol(x)
 
@@ -41,36 +46,55 @@ gofCopula <- function(copula, x, N = 1000, method = "mpl",
     if (n < 2) stop("There should be at least 2 observations")
 
     if (copula@dimension != p)
-      stop("The copula and the data should be of the same dimension")
+        stop("The copula and the data should be of the same dimension")
 
     if (!is.null(print.every)) {
         warning("Argument 'print.every' is deprecated. Please use 'verbose' instead.")
         verbose <- print.every > 0
     }
+    method <- match.arg(method)
+    estim.method <- match.arg(estim.method)
 
     gof <-
         switch(match.arg(simulation),
                "pb" = { ## parametric bootstrap
-                   gofPB(copula, x, N=N, method = method, verbose=verbose,
+		   gofPB(copula, x, N=N, method=method, estim.method=estim.method,
+			 verbose=verbose,
 			 optim.method=optim.method, optim.control=optim.control)
                },
                "mult" = { ## multiplier
-                   if (method == "mpl")
+                   if(method != "Sn")
+                       stop("Multiplier method for ", method, " not yet implemented")
+                   if (estim.method == "mpl")
                        gofMCLT.PL(copula, x, N=N,
                                   optim.method=optim.method, optim.control=optim.control)
-                   else if (method %in% c("irho","itau")) {
+                   else if (estim.method %in% c("irho","itau")) {
                        if (copula@dimension != 2)
                            stop("The simulation method 'mult' can be used in combination with the estimation methods 'irho' and 'itau' only in the bivariate case.")
-                       gofMCLT.KS(copula, x, N=N, method=method)
+                       gofMCLT.KS(copula, x, N=N, estim.method=estim.method)
                    }
                    else
-                       stop(sprintf("Invalid estimation method '%s'", method))
+                       stop(sprintf("Invalid estimation method '%s'", estim.method))
                },
                ## otherwise:
                stop("Invalid simulation method ", match.arg(simulation)))
     gof
 }
 
+##' @title Compute Sn (Cramer-von Mises) statistic; = (2) in Genest et al. (2009)
+##' @param u (n x d) matrix of copula observations
+##' @param copula 
+##' @return Sn
+##' @author Martin Maechler
+SnCvM <- function(u, copula) {
+    .C(cramer_vonMises,
+       n = as.integer(nrow(u)),
+       p = as.integer(ncol(u)),
+       as.double(u),
+       as.double(pCopula(u, copula)),
+       stat = double(1))$stat
+}
+
 ##' Goodness-of-fit test based on the parametric bootstrap
 ##' as proposed by Genest et al. (2008)
 ##'
@@ -79,34 +103,32 @@ gofCopula <- function(copula, x, N = 1000, method = "mpl",
 ##' if necessary, will be used as starting values in fitCopula
 ##' @param x the data
 ##' @param N the number of bootstrap replications
-##' @param method estimation method for the unknown parameter
+##' @param estim.method estimation method for the unknown parameter
 ##' @param verbose display progress bar is TRUE
 ##' @param optim.method for fitting
 ##' @param optim.control for fitting
 ##' @return an object of class 'htest'
 ##' @author Ivan Kojadinovic
-gofPB <- function(copula, x, N, method, verbose, optim.method, optim.control)
+gofPB <- function(copula, x, N, method, estim.method, verbose, optim.method, optim.control)
 {
     n <- nrow(x)
     p <- ncol(x)
-
     ## make pseudo-observations
-    u <- apply(x,2,rank)/(n+1)
+    u <- pobs(x)
 
-    ## fit the copula
-    fcop <- fitCopula(copula, u, method, estimate.variance=FALSE,
+    ## fit the copula and compute the test statistic
+    fcop <- fitCopula(copula, u, method=estim.method, estimate.variance=FALSE,
                       optim.method=optim.method, optim.control=optim.control)@copula
-
-    ## compute the test statistic
-    s <- .C(cramer_vonMises,
-            as.integer(n),
-            as.integer(p),
-            as.double(u),
-            as.double(pCopula(u, fcop)),
-            stat = double(1))$stat
+    
+    T <- if(method == "Sn") {
+        SnCvM(u, fcop)
+    } else {
+        ## transform + test statistic
+        gofTstat(rtrafo(u, fcop), method=method)
+    }
 
     ## simulation of the null distribution
-    s0 <- numeric(N)
+    T0 <- numeric(N)
     if (verbose) {
 	pb <- txtProgressBar(max = N, style = if(isatty(stdout())) 3 else 1) # setup progress bar
 	on.exit(close(pb)) # and close it on exit
@@ -114,29 +136,30 @@ gofPB <- function(copula, x, N, method, verbose, optim.method, optim.control)
     # if (print.every > 0)
     #    cat(paste("Progress will be displayed every", print.every, "iterations.\n"))
     for (i in 1:N) {
-        #if(print.every > 0 && i %% print.every == 0) cat(paste("Iteration",i,"\n"))
-        u0 <- apply(rCopula(n, fcop),2,rank)/(n+1)
+        ## (4.1)
+        u0 <- pobs(rCopula(n, fcop))
 
-        ## fit the copula
-        fcop0 <-  fitCopula(copula, u0, method, estimate.variance=FALSE,
-                            optim.method=optim.method, optim.control=optim.control)@copula
+        ## fit copula and compute S_n
+	fcop0 <- fitCopula(copula, u0, method=estim.method, estimate.variance=FALSE,
+			   optim.method=optim.method, optim.control=optim.control)@copula
 
-        s0[i] <- .C(cramer_vonMises,
-                    as.integer(n),
-                    as.integer(p),
-                    as.double(u0),
-                    as.double(pCopula(u0, fcop0)),
-                    stat = double(1))$stat
+        T0[i] <- if(method == "Sn") {
+            SnCvM(u0, fcop0)
+        } else {
+            ## transform + test statistic
+            gofTstat(rtrafo(u0, fcop0), method=method)
+        }
 
         if (verbose) setTxtProgressBar(pb, i) # update progress bar
     }
 
     structure(class = "htest",
-              list(method = paste("Parametric bootstrap based GOF test with argument 'method' set to '",
-                   method, "'", sep = ""),
+	      list(method = sprintf(
+		   "Parametric bootstrap based GOF test with 'method'=\"%s\", 'estim.method'=\"%s\"",
+		   method, estim.method),
                    parameter = c(parameter = fcop@parameters),
-                   statistic = c(statistic = s),
-                   p.value = (sum(s0 >= s)+0.5)/(N+1),
+                   statistic = c(statistic = T),
+                   p.value = (sum(T0 >= T) +0.5)/(N +1),
                    data.name = deparse(substitute(x))))
 }
 
@@ -160,20 +183,20 @@ influ.add <- function(x0, y0, influ1, influ2)
 ##' @param cop is a copula of the desired family
 ##' @param x the data
 ##' @param N number of multiplier replications
-##' @param method fitting method
+##' @param estim.method fitting method
 ##' @return an object of class 'htest'
 ##' @author Ivan Kojadinovic
-gofMCLT.KS <- function(cop, x, N, method)
+gofMCLT.KS <- function(cop, x, N, estim.method)
   {
-    stopifnot(method %in% c("irho","itau"), is.matrix(x))
+    stopifnot(estim.method %in% c("irho","itau"), is.matrix(x))
     n <- nrow(x)
     p <- 2
 
     ## make pseudo-observations
-    u <- apply(x,2,rank)/(n+1)
+    u <- pobs(x)
 
     ## fit the copula {*not* calling optim() ..}
-    cop <- fitCopula(cop, u, method=method, estimate.variance=FALSE)@copula
+    cop <- fitCopula(cop, u, method=estim.method, estimate.variance=FALSE)@copula
 
     ## compute the test statistic
     s <- .C(cramer_vonMises_grid,
@@ -186,10 +209,10 @@ gofMCLT.KS <- function(cop, x, N, method)
             stat = double(1))$stat
 
     ## prepare influence coefficients
-    if (method == "itau") ## kendall's tau
+    if (estim.method == "itau") ## kendall's tau
         influ <- 4 * (2 * pCopula(u, cop) - u[,1] - u[,2]
                       + (1 - tau(cop))/2) / dTau(cop)
-    else if (method == "irho") ## Spearman's rho
+    else if (estim.method == "irho") ## Spearman's rho
         influ <- (12 * (u[,1] * u[,2] + influ.add(u, u, u[,2],u[,1])) -
                   3 - rho(cop)) / dRho(cop)
 
@@ -205,8 +228,8 @@ gofMCLT.KS <- function(cop, x, N, method)
              s0 = double(N))$s0
 
     structure(class = "htest",
-              list(method = paste("Multilplier GOF test with argument 'method' set to '",
-                   method, "'", sep = ""),
+              list(method = sprintf("Multiplier GOF test with 'estim.method'=\"%s\"",
+                   estim.method),
                    parameter = c(parameter = cop@parameters),
                    statistic = c(statistic = s),
                    p.value = (sum(s0 >= s)+0.5)/(N+1),
@@ -269,7 +292,7 @@ gofMCLT.PL <- function(cop, x, N, optim.method, optim.control)
     p <- ncol(x)
 
     ## make pseudo-observations
-    u <- apply(x,2,rank)/(n+1)
+    u <- pobs(x)
 
     ## fit the copula
     cop <- fitCopula(cop, u, method="mpl", estimate.variance=FALSE,
@@ -297,7 +320,7 @@ gofMCLT.PL <- function(cop, x, N, optim.method, optim.control)
              s0 = double(N))$s0
 
     structure(class = "htest",
-              list(method = "Multilplier GOF test with argument 'method' set to 'mpl'",
+              list(method = "Multiplier GOF test with 'method'=\"mpl\"",
                    parameter = c(parameter = cop@parameters),
                    statistic = c(statistic = s),
                    p.value = (sum(s0 >= s)+0.5)/(N+1),
