@@ -90,7 +90,7 @@ indepTest <- function(x, d, alpha=0.05)
         stop("data cannot contain missing values")
     if (nrow(x) < 2)
         stop("data should contain more than 2 rows")
-    if (class(d) != "indepTestDist")
+    if (!inherits(d, "indepTestDist"))
         stop("d should be obtained by means of the function empcopu.simulate")
     if (ncol(x) != d$data.dimension)
       stop("d was not obtained from simulations based on data whose dimension is equal to that of x")
@@ -230,7 +230,7 @@ serialIndepTest <- function(x, d, alpha=0.05)
       stop("data cannot contain missing values")
     if (length(x) < 2)
       stop("data should contain more than 2 observations")
-    if (class(d) != "serialIndepTestDist")
+    if (!inherits(d, "serialIndepTestDist"))
       stop("d should be obtained by means of the function empcops.simulate")
     n <- length(x)
     if (n != as.integer(d$sample.size))
@@ -534,5 +534,5 @@ print.indepTest <- function(x, ...)
   cat("Combined p-values from the Mobius decomposition:\n")
   cat("  ", x$fisher.pvalue, " from Fisher's rule,\n")
   cat("  ", x$tippett.pvalue, " from Tippett's rule.\n")
-
+  invisible(x)
 }
